@@ -3,6 +3,8 @@ package Fey::Meta::FK;
 use strict;
 use warnings;
 
+our $VERSION = '0.28';
+
 use Fey::Exceptions qw( param_error );
 
 use Moose;
@@ -24,9 +26,10 @@ has associated_class =>
     );
 
 has name =>
-    ( is         => 'ro',
-      isa        => 'Str',
-      lazy_build => 1,
+    ( is      => 'ro',
+      isa     => 'Str',
+      lazy    => 1,
+      builder => '_build_name',
     );
 
 has namer =>
@@ -48,9 +51,10 @@ has foreign_table =>
     );
 
 has is_cached =>
-    ( is         => 'ro',
-      isa        => 'Bool',
-      lazy_build => 1,
+    ( is      => 'ro',
+      isa     => 'Bool',
+      lazy    => 1,
+      builder => '_build_is_cached',
     );
 
 
