@@ -3,6 +3,8 @@ package Fey::Meta::HasMany::ViaFK;
 use strict;
 use warnings;
 
+our $VERSION = '0.28';
+
 use List::MoreUtils qw( any );
 
 use Moose;
@@ -12,9 +14,10 @@ extends 'Fey::Meta::HasMany';
 
 
 has 'fk' =>
-    ( is         => 'ro',
-      isa        => 'Fey::FK',
-      lazy_build => 1,
+    ( is      => 'ro',
+      isa     => 'Fey::FK',
+      lazy    => 1,
+      builder => '_build_fk',
     );
 
 has 'order_by' =>
