@@ -3,18 +3,22 @@ package Fey::ORM::Table;
 use strict;
 use warnings;
 
+our $VERSION = '0.28';
+
 use Class::MOP;
 use Fey::Meta::Class::Table;
 use Fey::Object::Table;
 
 use Moose ();
 use Moose::Exporter;
+use Moose::Util::MetaRole;
+use MooseX::ClassAttribute::Role::Meta::Class;
 use MooseX::Params::Validate qw( pos_validated_list );
 
 Moose::Exporter->setup_import_methods
-    ( with_caller => [qw( has_table has_policy has_one has_many transform )],
-      as_is       => [qw( inflate deflate handles )],
-      also        => 'Moose'
+    ( with_meta => [qw( has_table has_policy has_one has_many transform )],
+      as_is     => [qw( inflate deflate handles )],
+      also      => 'Moose'
     );
 
 sub init_meta
@@ -31,16 +35,16 @@ sub init_meta
 
 sub has_table
 {
-    my $caller  = shift;
+    my $meta = shift;
 
     my ($table) = pos_validated_list( \@_, { isa => 'Fey::Table' } );
 
-    $caller->meta()->_associate_table($table);
+    $meta->_associate_table($table);
 }
 
 sub has_policy
 {
-    my $caller = shift;
+    my $meta   = shift;
     my $policy = shift;
 
     unless ( ref $policy )
@@ -50,12 +54,12 @@ sub has_policy
         $policy = $policy->Policy();
     }
 
-    $caller->meta()->set_policy($policy);
+    $meta->set_policy($policy);
 }
 
 sub transform
 {
-    my $caller = shift;
+    my $meta = shift;
 
     my @p;
 
@@ -65,7 +69,7 @@ sub transform
 
     for my $name (@_)
     {
-        $caller->meta()->_add_transform( $name => %p );
+        $meta->_add_transform( $name => %p );
     }
 }
 
@@ -91,7 +95,7 @@ sub handles ($)
 
 sub has_one
 {
-    my $caller = shift;
+    my $meta = shift;
 
     my %p;
     if ( @_ == 1 )
@@ -105,12 +109,12 @@ sub has_one
         %p = ( %p, @_ );
     }
 
-    $caller->meta()->add_has_one(%p);
+    $meta->add_has_one(%p);
 }
 
 sub has_many
 {
-    my $caller = shift;
+    my $meta = shift;
 
     my %p;
     if ( @_ == 1 )
@@ -125,7 +129,7 @@ sub has_many
 
     }
 
-    $caller->meta()->add_has_many(%p);
+    $meta->add_has_many(%p);
 }
 
 1;
@@ -170,7 +174,7 @@ Calling this function also generates a number of methods and
 attributes in the calling class.
 
 First, it generates one attribute for each column in the associated
-table. Of course, this assumes that your columns are namde in such a
+table. Of course, this assumes that your columns are named in such a
 way as to be usable as Perl methods.
 
 It also generates a predicate for each attribute, where the predicate
@@ -208,7 +212,7 @@ lc $has_one_table->name() >>, and caching will be turned on.
 If you want to change any of the defaults, you can use the
 multi-argument form. In this case, the first argument is the name of
 the attribute or method to add. Then you can specify various
-parameters by name. You must spceify a C<table>, of course.
+parameters by name. You must specify a C<table>, of course.
 
 The C<fk> parameter is required when there is more than one foreign
 key between the two tables. Finally, you can turn off caching by
@@ -269,7 +273,7 @@ will be no specific order to the results returned.
 If you want to change any of the defaults, you can use the
 multi-argument form. In this case, the first argument is the name of
 the attribute or method to add. Then you can specify various
-parameters by name. You must spceify a C<table>, of course.
+parameters by name. You must specify a C<table>, of course.
 
 The C<fk> parameter is required when there is more than one foreign
 key between the two tables. Finally, you can turn on caching by
