@@ -3,12 +3,13 @@ package Fey::Object::Iterator::FromSelect;
 use strict;
 use warnings;
 
+our $VERSION = '0.28';
+
 use Fey::Exceptions qw( param_error );
 
 use Devel::GlobalDestruction;
 use Moose;
 use MooseX::SemiAffordanceAccessor;
-use MooseX::AttributeHelpers;
 use MooseX::StrictConstructor;
 
 with 'Fey::ORM::Role::Iterator';
@@ -33,13 +34,14 @@ has bind_params =>
     );
 
 has _sth =>
-    ( is         => 'ro',
-      isa        => 'DBI::st',
-      lazy_build => 1,
-      writer     => '_set_sth',
-      predicate  => '_has_sth',
-      clearer    => '_clear_sth',
-      init_arg   => undef,
+    ( is        => 'ro',
+      isa       => 'DBI::st',
+      writer    => '_set_sth',
+      predicate => '_has_sth',
+      clearer   => '_clear_sth',
+      init_arg  => undef,
+      lazy      => 1,
+      builder   => '_build_sth',
     );
 
 has 'attribute_map' =>
@@ -49,10 +51,11 @@ has 'attribute_map' =>
     );
 
 has _merged_attribute_map =>
-    ( is         => 'ro',
-      isa        => 'HashRef[HashRef[Str]]',
-      lazy_build => 1,
-      init_arg   => undef,
+    ( is       => 'ro',
+      isa      => 'HashRef[HashRef[Str]]',
+      init_arg => undef,
+      lazy     => 1,
+      builder  => '_build_merged_attribute_map',
     );
 
 no Moose;
@@ -119,7 +122,7 @@ sub _get_next_result
     return \@result;
 }
 
-sub _build__sth
+sub _build_sth
 {
     my $self = shift;
 
@@ -130,7 +133,7 @@ sub _build__sth
     return $sth;
 }
 
-sub _build__merged_attribute_map
+sub _build_merged_attribute_map
 {
     my $self = shift;
 
@@ -382,9 +385,9 @@ map would look something like this:
       );
 
 The keys in the mapping are positions in the list of C<SELECT> clause
-elements. The numbers start from zero (0) just like a Perl array. The
-values are themselves a hash reference specifycing a "class" and
-"attribute" of that class.
+elements. The numbers start from zero (0) just like a Perl array. The values
+are themselves a hash reference specifying a "class" and "attribute" of that
+class.
 
 This explicit mapping is useful for more "exotic" queries. For example:
 
